function [P,T] = gen_mesh(a,b,c,d,m,n)

% Input:
% - a,b,c,d: Definieren das Rechtecks [a,b] x [c,d]:
%
%   (a,d)--------------------------(b,d)
%     |                              |
%     |                              |
%     |                              |
%   (a,c)--------------------------(b,c)
%
% - m: Anzahl der Teilintervalle in y-Richtung
% - n: Anzahl der Teilintervalle in x-Richtung
%
% Output:
% - T: Matrix, welche in der i-ten Zeile die Indizes der zum i-ten Dreieck
% gehoerenden Knoten enthaelt.
% - P: Matrix, welche in der j-ten Zeile die (x,y)-Koordinaten des j-ten
% Knotens enthaelt.



hx = (b-a)/n; % Schrittweite in x-Richtung
hy = (d-c)/m; % Schrittweite in y-Richtung

% erstelle Punktegitter
x = a:hx:b; 
y = c:hy:d;
[X,Y] = meshgrid(x,y);

% Transponieren (aendert nur die Zaehlrichtung der Punkte - optional!)
Xtransp = X';
Ytransp = Y';

P = [Xtransp(:),Ytransp(:)]; 
% Somit ist die Zaehlrichtung der Punkte von links unten nach rechts oben
% (zuerst x-Richtung, dann y-Richtung):
%
%   (a,d)--------------------------(b,d)
%     |                              |
%     x6                             |
%     |                              |
%     x1-----x2------x3------x4-----x5
%
% usw.

N = n+1; % Anzahl Punkte in x-Richtung. 
% n ist die Anzahl der Dreiecke in x-Richtung
% m ist die Anzahl der Dreiecke in y-Richtung

% Wir zerteilen unsere Vierecke von unten links nach oben rechts, vgl. Abb1
% des Uebungslattes (links). Damit gibt es lower-right Triangles (T_lr) und
% upper-left Triangles (T_ul). Beispiel:
%
% Ein lower-right Dreieck mit Punktereihenfolge P1, P2, P3:
%
%           P3
%         /  |
%       /    |
%     /      |
%   P1------P2
%
% Ein upper-left Dreieck mit Punktereihenfolge P1, P2, P3:
%
%   P2------P3
%   |      /
%   |    /
%   |  /
%   P1
%
% Damit ergeben sich die Dreiecksindizes wie folgt.
T_lr = zeros(m*n,3);
T_ul = zeros(m*n,3);

for i = 1:m % Schleife ueber die "Reihen" der Triangulierung in y-Richtung
    
    % lower-right Dreiecksindizes
    T_lr((i-1)*n+1:i*n,1) = (i-1)*N+1:i*N-1; % P1
    T_lr((i-1)*n+1:i*n,2) = (i-1)*N+2:i*N; % P2
    T_lr((i-1)*n+1:i*n,3) = i*N+2:(i+1)*N; % P3
    
    % upper-left Dreiecksindizes
    T_ul((i-1)*n+1:i*n,1) = (i-1)*N+1:i*N-1; % P1
    T_ul((i-1)*n+1:i*n,2) = i*N+1:(i+1)*N-1; % P2
    T_ul((i-1)*n+1:i*n,3) = i*N+2:(i+1)*N; % P3
end
T = [T_lr;T_ul]; 

